@@ -1,6 +1,6 @@
 /*
  *  R : A Computer Language for Statistical Data Analysis
- *  Copyright (C) 2001-2017  The R Core Team.
+ *  Copyright (C) 2001-2022  The R Core Team.
  *
  *  This header file is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,8 +34,9 @@
 
 #include <R_ext/Boolean.h>
 
-/* called with a variable argument set */
-typedef void * (*DL_FUNC)();
+/* Called with a variable argument set after casting to a compatible
+   function pointer.  */
+typedef void * (*DL_FUNC)(void);
 
 typedef unsigned int R_NativePrimitiveArgType;
 
@@ -84,16 +85,21 @@ int R_registerRoutines(DllInfo *info, const R_CMethodDef * const croutines,
 Rboolean R_useDynamicSymbols(DllInfo *info, Rboolean value);
 Rboolean R_forceSymbols(DllInfo *info, Rboolean value);
 
+/* Not API */
 DllInfo *R_getDllInfo(const char *name);
 
 /* To be used by applications embedding R to register their symbols
-   that are not related to any dynamic module */
+   that are not related to any dynamic module/
+
+   Not API
+*/
 DllInfo *R_getEmbeddingDllInfo(void);
 
 typedef struct Rf_RegisteredNativeSymbol R_RegisteredNativeSymbol;
 typedef enum {R_ANY_SYM=0, R_C_SYM, R_CALL_SYM, R_FORTRAN_SYM, R_EXTERNAL_SYM} NativeSymbolType;
 
 
+/* Not API */
 DL_FUNC R_FindSymbol(char const *, char const *,
 		       R_RegisteredNativeSymbol *symbol);
 
@@ -102,6 +108,8 @@ DL_FUNC R_FindSymbol(char const *, char const *,
    for use from C code in a package.  The registration part probably
    ought to be integrated with the other registrations.  The naming of
    these routines may be less than ideal.
+
+   Declarations in the manual, so API
 */
 
 void R_RegisterCCallable(const char *package, const char *name, DL_FUNC fptr);
