@@ -1,7 +1,8 @@
 ### This used to be in   example(smooth) before we had package-specific demos
+#  Copyright (C) 1997-2009 The R Core Team
 
 require(stats); require(graphics); require(datasets)
-op <- par(ask = interactive(), mfrow = c(1,1))
+op <- par(mfrow = c(1,1))
 
 ## The help(smooth) examples:
 example(smooth, package="stats")
